# FieldOptions8

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**is_reversed** | **bool** | Whether the linked records are sorted in reverse order | [optional] 
**linked_table_id** | **str** | The id of the linked table | [optional] 
**prefers_single_record_link** | **bool** | Whether the field prefers a single linked record | [optional] 
**inverse_link_field_id** | **str** | The id of the inverse linked field in the linked table | [optional] 
**view_id_for_record_selection** | **str** | The id of the view used to select linked records | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

